Скидки и распродажи на slivki.by
Description: Грандиозные скидки и акции: рестораны, салоны красоты, клубы, спорт, досуг... Лучшие цены в популярных заведениях и магазинах Минска на Slivki.by!
Keywords: скидки, распродажи, рекламные акции, Минск, кредит, дисконтная карта, карточка, новогодние скидки, Сезонные Распродажи и скидки, праздничная распродажа, распродажа одежды, приз, подарок, сюрприз, сувенир, РБ, Республика Беларусь, единая дисконтная система Беларуси, выгода, товары и услуги выгодно, экономия, промо, Акция, магазин, успеть купить, Модная одежда, фирмы, компании, рестораны, Минск, сезон потребитель дешево качественно быстро удобно продавец Новый товар

Регистрация Я начинаю пользоваться сайтом и получу Бонус 8000 руб.
Город Минск Брест Витебск Гомель Гродно Могилев Россия Other countries
| Вход Я уже имею аккаунт на сайте.
Я забыл(а) пароль Восстановление пароля |
Активация аккаунта Вам было отправлено письмо с активационной ссылкой. Пожалуйста, перейдите на ваш почтовый ящик и завершите регистрацию. |
## Бонус 10.000 руб! ## За каждые полученные 10 кодов в течение 30 дней... начисляется Бонус 10.000 руб. Берите больше кодов себе и близким! Больше кодов - больше Бонус! | ## Бонус за репост! ## За репост акции в социальную сеть вы... получаете 500 рублей на счет. Каждый день вы можете получать 1.000 руб. на свой счет или 30.000 руб. в месяц, если выберите наиболее понравившуюся одну или две акции и отметите ее в Твиттере или Вконтакте. За один день можно совершить не более двух кликов, отметив либо две акции в одной соц. сети, либо одну акцию в двух соц. сетях. Для этого необходимо открыть условия акции и кликнуть на выбор: | ## Бонус за пополнение счета ## При пополнении счета по телефону или webmoney... вы получаете Бонус 10.000 рублей за каждые единовременно зачисленные 75.000 рублей. Пополненный счет позволит вам получать коды в любом месте и в любое время суток без звонка оператору.
Справка: (029)
| 608 22 22
| 508 22 22

Разместить акцию
Разместить скидки города

- Услуги 3249

  Популярное за 24 часа 500 | Новые 119
  Подарочные сертификаты 181 | Новый год 337
  Рекомендуемые 84 | Салоны красоты 1327
  Еда 49 | VRK Travel 22
  Развлечения 108 | Авто 204
  Здоровье и Спорт 214 | Туризм 432
  Детям 97 | Обучение 52
  Прочие 153 | Свадьба 35
  Гарантия качества руководителя 16 | Акции РБ 22

- Товары и подарки 855
- Бесплатные коды 104
- Скидки в Минске SALE

Новость дня:

| Качественный и доступный перманентный макияж? - Да! Со скидкой 60%!

Посмотреть еще
Комментарии live:
Акция: Художественная татуировка в студии «Slim» от 150 000 руб.
Отлично! Если ваша мастер согласна за это взяться, то я подойду покажу "полотно" в живую, а не на фото, чтоб наглядно можно было оценить ситуацию и решить, что с этим можно сделать)))
Акция: Солярий в студии загара "Подсолнухи" за 2700руб/мин
Жаль, что на Пушкинскую не действует акция))) Мне там ближе к дому)))) Но на Коласа нравилось всегда больше - там и по воскресеньям работают, и вообще эффект от солярия заметнее. В целом солярии неплохие, только вот ВИП-кабинки я их не понимаю, мне больше нравится загорать постепенно. В ВИП ну очень много ламп)))) Администраторы приветливые.
Акция: Послеремонтная и генераль- ная уборка от 11.000 руб.
воспользовалась купоном, очень довольна уборкой! мыли мою однакомнатную квартиру часов 5, везде такая чистота, средства профессиональные отмывают все до блеска. спасибо
Посмотреть еще
Скидки в городе SALE:
Акции SOS! Sale Outlet Stock

- | Скидка «10%» к вашему Дню рождения в сети универсальных магазинов «BIGZZ»!

  Добавлено 7 декабря
  Специальное предложение ко Дню рождения для участников Клуба друзей «BIGZZ».

- | Акция в Sister's! "Скажи "КОЗА" и получи капу$ту!"

  Добавлено 7 декабря

- | Акция от SMTURBO для автомобилей Фольксваген Групп!

  Добавлено 27 ноября

- | Скидки до 60% на светильники в салоне "Фламинго"!

  Добавлено 13 ноября
  Ваши покупки - наши подарки!

- | Еще больше модных покупок! Скидка 25% в салонах обуви BASCONI!

  Добавлено 5 ноября
  В салонах обуви BASCONI скидка 25% на все сапоги и ботинки из осенней коллекции.

- Новогодняя музыкальная шоу программа "Яркий свет" со скидкой 10%!

  Добавлено 30 октября

- | Сливочные бонусы! Платите 5 950 руб. за код и получайте 30 000 руб. на счет

  Добавлено 16 октября

Торговые центры

- | Акция "Красная цена" в магазинах "Еврооопт"!

  Добавлено 7 декабря

- | Скидка «10%» к вашему Дню рождения в сети универсальных магазинов «BIGZZ»!

  Добавлено 7 декабря
  Специальное предложение ко Дню рождения для участников Клуба друзей «BIGZZ».

- | Рождественская распродажа в ЦУМе!

  Добавлено 7 декабря

- | Акция в супермаркетах и суперсторах "Родная сторона"!

  Добавлено 2 декабря

- | Предложения от гипермаркета "Алми"!

  Добавлено 2 декабря

- | Специальное предложение в гипермаркете Green!

  Добавлено 27 ноября

- | Акция в сети магазинов "Златка"!

  Добавлено 27 ноября

- | Акционное предложение в сети магазинов "Рублевский"!

  Добавлено 26 ноября

- | Готовимся к праздникам вместе с "Гиппо"!

  Добавлено 26 ноября

Одежда. Обувь. Аксессуары

- | Акция в Sister's! "Скажи "КОЗА" и получи капу$ту!"

  Добавлено 7 декабря

- Скидка 50% на определенные модели в Women’secret!

  Добавлено 6 декабря

- | Акция в МЕГАТОП! Скидки до 70%!

  Добавлено 5 декабря

- | Скидки в магазине джинсовой одежды LEE WRANGLER!

  Добавлено 4 декабря

- | Скидки до 30% в магазинах "Европейская обувь"!

  Добавлено 3 декабря

- | Рождественские скидки на сумки от ECOBAGS.BY!

  Добавлено 2 декабря

- Нижнее мужское белье со скидкой 47%!

  Добавлено 30 ноября

- | Скидка 30% на покупку домашних сапожек Burlesco!

  Добавлено 28 ноября

- | Акция в Jennyfer! Вторая покупка за полцены!

  Добавлено 27 ноября

- | Скидки до 30% в MEXX!

  Добавлено 26 ноября
  Скидка до 30% на некоторые модели пальто и курток!

- | Женские польские сапоги и полусапожки со скидкой 25%!

  Добавлено 24 ноября

- | Скидка до 50% в Colin's!

  Добавлено 23 ноября

- | Акция в BOSS HUGO BOSS! Совершите покупку и получите сертификат!

  Добавлено 23 ноября

- Скидка до 50% на продажу и прокат свадебных платьев!

  Добавлено 22 ноября

- | Открылся магазин постоянных распродаж в ТЦ "Магнит"! Скидки достигают 90%!

  Добавлено 21 ноября

- Акция в салонах Gerry Weber! Чем больше покупок, тем больше скидка!

  Добавлено 21 ноября
  В Gerry Weber стартует новая акция!

- | Акция в SMS! Купи 3 вещи по цене 2!

  Добавлено 21 ноября
  Заманчивая акция стартует в SMS!

- | Месяц выгодных покупок в "Элема"!

  Добавлено 10 ноября

- | Еще больше модных покупок! Скидка 25% в салонах обуви BASCONI!

  Добавлено 5 ноября
  В салонах обуви BASCONI скидка 25% на все сапоги и ботинки из осенней коллекции.

- | Бобруйск. Скидка 20% на женскую и детскую одежду в магазине Panda!

  Добавлено 21 октября

- | Магазин одежды BAON. Скидка 15% на первую покупку!

  Добавлено 5 октября

- | Игра «Марко». Приготовься к новым маршрутам!

  Добавлено 22 сентября

Кафе и рестораны

- | Пирог + чашка кофе за 50 000 руб. в Loft cafe!

  Добавлено 8 декабря

- | Скидка 20% на все меню в баре "Мускат"!

  Добавлено 8 декабря

- | Акция в SORSO di espresso! Безлимитный фильтр кофе!

  Добавлено 2 декабря

- | Скидка на горячие напитки в спорт-баре "Bristle"!

  Добавлено 24 ноября

- | Скидка 20% на меню в гриль-хаус "Меxico"!

  Добавлено 24 ноября

- | Скидка 50% на сэндвичи и пиццу в пиццерии "Маргарита"!

  Добавлено 5 ноября

- | Акция 7BIG в кофейне «Coffeeberry»!

  Добавлено 4 ноября

- | В ENZO cafe еда на вынос со скидкой 25%!

  Добавлено 3 ноября

- Скидка 30% на меню в ресторане "Очаг"!

  Добавлено 21 октября

- | В Terra Pizza кофе espresso на вынос теперь дешевле на 30%!

  Добавлено 1 октября

- | Бургеры по специальной цене от ресторана Goody's!

  Добавлено 30 сентября

- Скидка 20% на все вечернее меню кухни в пабе "Бочка"!

  Добавлено 11 сентября
  C вc. по чт. скидка 20 % на все вечернее меню кухни!

- | Отметь день рождение в Chill Out!

  Добавлено 7 сентября

- | Предложение для именинников от Loft cafe!

  Добавлено 26 августа

- Скидка 20% на меню именинникам в "Про кафе"!

  Добавлено 26 июля
  В «Про кафе» именинникам скидка 20%.

Мебель. Интерьер

- | Акция «Зимняя» в магазинах мебели BLACK RED WHITE!

  Добавлено 6 декабря

- Новогодняя скидка на подушку Vegas!

  Добавлено 5 декабря

- | Скидка 30% на двери "Европан"!

  Добавлено 5 декабря

- | Дизайн комнаты за 3 часа в Вашем присутствии всего за 280$!

  Добавлено 3 декабря

- | Проект дизайна интерьера со скидкой 55%!

  Добавлено 30 ноября

- | Vegas засыпает скидками!

  Добавлено 28 ноября

- | Зимнее снижение цен в салонах итальянской плитки и сантехники «Сквирел»!

  Добавлено 26 ноября

- | Акция "Подарок" от мебельной фабрики "Лагуна"!

  Добавлено 24 ноября

- | Натяжные потолки со скидкой до 40%!

  Добавлено 22 ноября

- | Разработка дизайн проекта интерьера со скидкой 50%

  Добавлено 18 ноября

- | Скидки до 60% на светильники в салоне "Фламинго"!

  Добавлено 13 ноября
  Ваши покупки - наши подарки!

- Сезонные скидки до 30% на товары для дома!

  Добавлено 5 октября

Бытовая техника

- | Акция в магазинах Silverado!

  Добавлено 8 декабря

- | Готовимся к Новому году вместе с магазинами «Электросила»!

  Добавлено 7 декабря
  С 31 января по 2 февраля 2014 года во всех магазинах «ЭЛЕКТРОСИЛА» скидки от 20 до 50%.

- | Улетные цены в магазинах "ТEXNO Плюс"!

  Добавлено 6 декабря

- | "5 Элемент": Мы разбили цены!

  Добавлено 24 ноября

Красота и здоровье

- | Предновогодние скидки в салоне красоты "Ветка Сакуры"!

  Добавлено 3 декабря

- | Обучающий курс "Визаж для себя" со скидкой 20%!

  Добавлено 29 ноября

- Скидка 7% на лазерное омоложение лица в "Linline"!

  Добавлено 29 ноября

- | Новогодние сертификаты от "Linline" со скидкой 10%

  Добавлено 29 ноября

- Акции в салоне красоты "Он и Ты"!

  Добавлено 25 ноября

- Акция от клуба красоты Linline и тур. агентства "Туссон Вояж"!

  Добавлено 21 октября

Косметика и парфюмерия

- | Специальная цена на набор солнечной линии SELECTIVE в магазине "Пирамида"!

  Добавлено 8 декабря

- | Акции в магазинах красоты "Космо"!

  Добавлено 8 декабря

- | Скидки на товары месяца в КРАВТ!

  Добавлено 5 декабря

- | Новогодние скидки на косметику, парикмахерские инструмент, канекалон!

  Добавлено 5 декабря

- | Акция в дискаунтере "Остров чистоты"!

  Добавлено 1 декабря

- | Акция в торговой сети Optima!

  Добавлено 30 ноября

- Скидка на наливные духи Reni + бесплатная доставка!

  Добавлено 30 ноября

- | Экономим вместе с Милой! Новогодний мешок Деда Мороза!

  Добавлено 29 ноября

- | Могилев. Именинникам скидка 10% на всю продукцию в магазине косметики "Ева"!

  Добавлено 20 ноября

- | Скидка до 50% на косметику в магазинах ДНК!

  Добавлено 4 ноября

Спорттовары

- Предновогодняя распродажа в магазинах Adidas!

  Добавлено 3 декабря

Детям

- | Скидка до 40% на детскую мебель в магазине Babby market!

  Добавлено 9 декабря

- Видеопоздравление от Деда Мороза!

  Добавлено 7 декабря

- | Новогодние скидки до -50% в "Буслiк"!

  Добавлено 5 декабря

- Скидки на наборы для купания от Mothercare!

  Добавлено 4 декабря

- Скидки 30% на всю продукцию от ТМ «Оранжевый Слон»!

  Добавлено 3 декабря

Стройматериалы

- | Акции в строительном гипермаркете "Mile"!

  Добавлено 6 декабря

- | Специальное предложение декабря в "ОМА"!

  Добавлено 3 декабря

Авто

- | Акция от SMTURBO для автомобилей Фольксваген Групп!

  Добавлено 27 ноября

- Кузовной ремонт и покраска авто со скидкой 20%!

  Добавлено 22 ноября

Прочее

- | Скидка на лизны в магазине Optik.by!

  Добавлено 9 декабря

- Проектор Smart WIFI 3D со скидкой 30%!

  Добавлено 4 декабря

- Акция "Сверкай" в сети ювелирных магазинов "7 КАРАТ"!

  Добавлено 4 декабря

- Срочная польская шенген-мультивиза "за покупками" за 80$

  Добавлено 4 декабря

- | Скидка 100£ на групповую программу на весенних каникулах от Streamline!

  Добавлено 2 декабря

- | Оперативная чистка системы охлаждения ноутбука от Дедушки Мороза! Скидка 20%!

  Добавлено 1 декабря

- | Большие плюшевые мишки со скидкой до 50%!

  Добавлено 25 ноября

- Предновогодние скидки на французскую посуду LUMINARC!

  Добавлено 23 ноября

- | Cкидка 30% на курсы по рисованию в ELEVEN-O-FOUR!

  Добавлено 2 ноября

- Новогодняя музыкальная шоу программа "Яркий свет" со скидкой 10%!

  Добавлено 30 октября

Показать
на карте

# Популярное за 24 часа (500)

Лазерная эпиляция на ультра- современном Palomar
ст.м. "пл. Победы"/ ст.м. "Уручье"
34636
-40%
Бассейн + джакузи + сауна + аквапарк-мини от 25.000/2 ч
ст.м. "Немига"
713
-50%
Лазерная эпиляция всего от 75.000 руб.
пр-т Машерова - ул. Богдановича
1976
-60%
Посмотреть весь раздел▼
Показать
на карте

# Новые (119)

Альтернатива пластике и ботоксу! Массаж лица + уход
Зеленый Луг
6
-50%
Шиномонтаж+грузы, подкачка колес, герметик от 100 000 руб.
ул. Щербакова - пер. Стахановский
9
-50%
Подарочные сертификаты для любимых по уходу за телом и лицом
р-н ст.м. "Фрунзенская"
3
-50%
Биотатуаж бровей хной + волосковым методом 3D от 115.000 руб.
Зеленый Луг
2
-50%
Spa-сертификаты для лица, тела, волос, рук от 130 000 руб.
ст.м. "Пушкинская"
2
-66%
Наборы для рисования "Ромб" от 129 000 руб.
ст.м. "Фрунзенская" + доставка
10
-48%
Новогодняя фотосессия, худ. портрет от 75 000 руб.
ст.м. "Грушевка"
1
-50%
Новый год 2015 в Вильнюсе от 100€/3 дня
Выезд: 31 декабря 2014 г.
8
-25€
Посмотреть весь раздел▼
Показать
на карте

# Подарочные сертификаты (181)

Салоны для мужчин (18) Салоны для женщин (63) Солярии (30) Авто (5) Тренажеры и фитнес (35) Прогулка верхом (1) Багги. Квадроциклы (2) Другое (9) Стоматология (1) Пострелять (3) Фотосессия (4) Все Подарочные сертификаты
17 Spa-сертификатов для нее, него и для двоих со скидкой до 53%
пр-т Партизанский - МКАД
2129
-53%
25 подарочных сертификатов от VIP-салона "Эгоист&ка"
Логойский тракт
3824
-55%
Подарочные сертификаты в центре эстетики "Fler" от 349 900р.
пр-т Партизанский - МКАД
565
-65%
Сертификаты -50%-54% чтобы быть в тонусе от S-line
ст.м. "Площадь Я.Коласа"
16
-54%
Сертификаты -54% чтобы быть в тонусе от S-line
р-н ТЦ "Рига"
8
-54%
Сертификат на погружение с аквалангом за 100 000 руб.
ст.м. "Академия наук"
41
-50%
Посмотреть весь раздел▼
Показать
на карте

# Новый год (337)

Гирлянды (5) Дед Мороз (23) Елки (9) Новогодние туры (132) Подарки (91) Подарочные сертификаты (67) Весь Новый год
Поздравление Деда Мороза и Снегурочки от 130 000 руб.
Выезд
207
-67%
Смартфон за 1.1 млн. + в подарок телефон и МР3 плеер
Доставка
216
-56%
Поздравление Деда Мороза у Вас дома от 160 000 руб.
Выезд
177
-69%
Посмотреть весь раздел▼
Показать
на карте

# Рекомендуемые (84)

ТОП 30 подарков (27) Популярный туризм (5) Все Рекомендуемые
Печать фото на холсте - фотокартины со скидкой!
Доставка
1564
-30%
Чистые ковры и мягкая мебель к Новому году от 23 000 руб.
Выезд
2800
-60%
Скидка на зеленый кофе с имбирём - всего от 88 000 руб.
Доставка + самовывоз
1536
-58%
Водостойкая Bluetooth колонка SAROS от 25$
ул. Долгобродская + доставка
57
-38%
Большой выбор дверей межкомнатных от 55$
Доставка
118
-до 40$
Скидки на эл. книги Amazon Kindle, Paperwhite, Nook, Sony
ул. Тимирязева + Доставка по РБ
652
-до 100$
Код: 0 руб.
Бижутерия с кристаллами Swarovski всего от 84 000 руб.
Доставка
573
-30%
Код: 0 руб.
Корпусная мебель и шкафы купе со скидкой 21%
выезд к заказчику+доставка
179
-21%
Код: 0 руб.
Женские польские сапоги и полусапоги со скидкой 35%
р-н Комаровки
1
-35%
Посмотреть весь раздел▼
Рекомендуем посмотреть: ТОП30 подарков (27) Аксессуары (39) Депиляция. Эпиляция (72) Мягкие игрушки (21) Перманент (18)
Показать
на карте

# Салоны красоты (1327)

VIP (4) B-flexy (29) LPG массаж (4) Spa и уход за телом (96) Выпрямление волос (46) Горячие ножницы (42) Депиляция. Эпиляция (72) Йога (12) Кедровая бочка (20) Коррекция фигуры (115) Лазер (15) Макияж (27) Маникюр (212) Массаж (64) Мужчинам (62) Наращивание волос (10) Наращивание ногтей (17) Обертывания (72) Окраска и мелирование (87) Педикюр (135) Перманент (18) Прически (61) Прокол ушей (16) Ресницы и брови (68) Свадьба (19) Сертификаты (93) Солярии (42) Стрижка женская (129) Татуировки (14) Тренажер Назарова (15) Тренажерный зал (3) Уход за волосами (206) Уход за лицом (224) Фитнес (22) Все Салоны красоты
Компании (84)
Fler (39) 5th Avenue (2) Body Jazz (5) Colibri SPA (11) CyndiCat's (7) DOMINIK (11) Healthy Joy на Победителей (13) Healthy Joy на Пушкина (8) L Studio (6) La Boutique De'Beaute (11) Lakme (18) Matiss (2) Mei Li (6) Naomi (10) Shvedov Time (2) S Line (4) Slim (18) Sonata (4) Sound Body (2) Tesori (10) Vanilla Studio (8) V-Studio (5) Акварель (17) Акрополь (5) Ароша (9) Биата Шарм (2) Бигуди (20) Бон Салон (6) Бронзаж (4) В гостях у Солнца (6) Валенсия (23) Вдохновение (6) Вега (11) Верона (5) Вианика на Лобанка (11) Вианика на Сердича (10) Вселенная (4) Габриель (9) Делакруа (1) Дива (28) Дива-Шарм (7) Для нее (20) Дом солнца (9) Екатерина (1) Жасмин (8) Индиго (5) Кабинет коррекции фигуры на Прушинских (5) Карамель (5) Катрин-стиль (10) Кокетка (2) Коса (20) КОСМЕД (3) Легенда (Schwarzkopf) (18) Ленуська (6) Леона (10) Ле Шарм (2) Лидия Шарм (4) Лилита (5) Место под солнцем (8) Метелица (1) Миксель (13) Мод дэ ля бутэ (14) Мэрилин (8) НадиКа (4) ОДи (14) Он и Ты (4) Пространство красоты (7) СаВера (1) Сага (6) Символ Бьюти (7) Сфера Фитнес (14) Те Амо (13) Тонус-студия (14) Тропикана (1) Унисон стиль (5) Фифа (7) Фрау Марта (5) Храм солнца (33) Цырульня у Прадмесцi (12) Шайнэст (3) Шарм (9) Эгоист&ка (18) Эмилия (5) Энжэл (4)
Биомолекулярное восстанов- ление волос от 159 900 руб.
пр-т Партизанский - МКАД
127
-58%
Безинъекционная мезотерапия лица от 150 000 руб.
пр-т Партизанский - МКАД
1228
-60%
Криолипосакция - интенсивное похудение к Новому году!
пр-т Партизанский - МКАД
1171
-93%
Гликолевый пилинг всего от 190 000 руб.
Немига
38
-55%
Маникюр, педикюр + долго- временное покрытие за 99 000 руб.
пр-т Партизанский - ул. Кошевого
253
-53%
Горячие ножницы + уход маслом аргана от 149 000 руб.
р-н ст.м. "Первомайская", отель "Пекин"
27
-55%
Кератиновое выпрямление волос всего от 140 000 руб.
Немига
47
-50%
Экспресс-похудение "Новогод- няя богиня" за 25 дней!
ст.м. "Институт Культуры"
137
-100%
Курс похудения на VacuStep от 45 000 руб.
ст.м. "Институт Культуры"
398
-51%
Наращивание и коррекция ногтей всего за 180 000 руб.
Академия наук
494
-50%
Поресничное наращивание ресниц от 180 000 руб.
Сухарево
56
-до 50%
Профессиональная депиляция всего от 30 000 руб.
ст.м. "Академия наук"
1039
-50%
Гигиеническая чистка +комп- лекс-уход за лицом от 160 000 руб.
ст.м. "Академия наук"
389
-56%
Фотоэпиляция в салоне "Лилита" от 55 000 руб.
Сухарево
921
-70%
Завивка волос ISO в Студии Сергеенко за 230 000 руб.
ст.м. "Парк Челюскинцев"
4
-50%
Подарочные сертификаты от 190 000 руб. на SPA-обертывание
ст.м. "Уручье"
84
-55%
«Слим-Экстрим» - 21-дневный комплекс по снижению веса
Зелёный Луг
259
-55%
Обертывания в Spa-капсуле всего от 250 000 руб.
ст.м. "Площадь Я.Коласа"
127
-50%
Посмотреть весь раздел▼
Показать
на карте

# Еда (49)

Суши (9) Пицца (9) Доставка (10) Кафе и рестораны (29) Еда на вынос (12) Паста и лазанья (3) Кофе (3) Торты (1) Мастер-классы (1) Сладкое (2) Другое (10) Вся Еда
Уголок романтики в кафе «Sobranie» - блюда от 17 500 руб.
пл. Независимости
438
-50%
2 высококлассных сорта кофе от 150 000 руб./кг
Доставка
0
-45%
Суши, суши-сеты от 7 500 руб. с доставкой
БИГЗ + Доставка
1744
-50%
Посмотреть весь раздел▼
Показать
на карте

# VRK Travel (22)

Новый год и Рождество (7) Весь VRK Travel
Акция! Тур в Вильнюс на автобусе бесплатно, шопинг + экскурсии
Выезд: 10.01, 11.01, 17.01, 18.01, 24.01, 25.01
2679
-100%
Рождественский тур в Варшаву за 49€/4 дня
Выезд: 25 декабря 2014 г.
313
-10€
Сказочная встреча Нового года в Юрмале за 69€/5 дней
Выезд: 29 декабря 2014 г.
51
-40€
Посмотреть весь раздел▼
Показать
на карте

# Товары и Подарки (406)

ТОП30 подарков (27) Авто (16) Аксессуары (39) ТЦ Силуэт (52) Бытовая техника (33) Варианты подарков (191) Головоломки (4) Детские (45) Для дома (61) Для кухни (26) Инструменты (4) Интим (8) Компьютеры и телефоны (23) Кофе (2) Мебель (13) Мягкие игрушки (21) Настольные игры (2) Парфюмерия и косметика (13) Подушки. Одеяла. Белье (12) Праздник (42) Сад. Огород (3) Сертификаты (35) Сладкое (3) Спорт (3) Средства гигиены (5) Цветы (21) Другое (59) Все Товары и Подарки
Компании (1)
Магазин низких цен (17)
Новинка! Фиксатор Valgus PRO от 89 000 руб.
Доставка
670
-65%
Код: 0 руб.
Скидка на электронную книгу Amazon Kindle 5 от 95$
ст.м. "Площадь Победы" + Доставка
2029
-40$
Код: 0 руб.
Магнитные кольца для похудения всего за 75 000 руб.
Доставка
227
-45%
Код: 0 руб.
Посмотреть весь раздел▼
Показать
на карте

# Развлечения (108)

Бассейны (3) Бильярд (4) Боулинг (1) Детские центры (5) Караоке (7) Картинг. Багги. Квадроциклы. (7) Клубы. Досуг (22) Концерты.Спектакли.Выставки (11) Прогулка верхом (8) Пострелять (15) Прокат (13) Сквош (1) Сертификаты (6) Другое (26) Все Развлечения
Адреналиномания! Картинг-клуб "Форсаж" за 50 000 руб.
р-н пл. Бангалор
2741
-50%
7D, 5D, автоматы-симуляторы в аквапарке за полцены!
пр-т Победителей, аквапарк "Лебяжий"
515
-50%
Два часа сауны по цене одного в центре Body Jazz!
Немига
227
-50%
Посмотреть весь раздел▼
Показать
на карте

# Авто (204)

Авто из США (1) Автозапчасти и масла (1) Автомойки (25) Автотовары (13) Замена жидкостей (19) Аккумуляторы (3) Аргонная сварка (3) Диагностика подвески (21) Замена тормозных колодок (6) Заправка кондиционера (15) Компьютерная диагностика (14) Нано (8) Сертификаты (2) Развал-схождение (3) Правка и раскатка дисков (10) Счет-справка (2) Удаление вмятин (3) Химчистки и полировки (29) Шиномонтаж (31) Другое (28) Все Авто
Ремонт и реставрация салона авто всего от 10$
ул. Железнодорожная
25
-50%
Премиум химчистка авто к Новому Году от "Грязи Нет"
ул. Долгобродская - ул. Уральская
2034
-60%
За качеством вам сюда! Химчистка со скидкой 50%!
2 адреса в Минске
136
-50%
Шиномонтаж, нарезка, ремонт шин от 75 000 руб.
ул. Маяковского
326
-50%
Дистанционное управление ц/з авто за 250 000 руб.
ул. Смоленская - ул. Захарова
1
-50%
Новогодние подарочные сер- тификаты на обслуживание авто от Корпорации AV
ТЦ "Арена Сити" + Выезд
164
-50%
Посмотреть весь раздел▼
Показать
на карте

# Здоровье и Спорт (214)

Бани и сауны (21) Бассейны (4) Диагностика. Обследование. (8) Йога (20) Кедровая бочка (11) Массаж (33) Медцентры (31) Сквош (1) Стоматология (15) Танцы (19) Тренажерный зал (20) УЗИ (13) Фитнес (45) Товары (8) Другое (13) Весь Здоровье и Спорт
Бодифлекс, Оксисайз, пилатес, танцы - худеем без диет!
ст-н "Динамо"
78
-100%
Бассейн + джакузи + сауна + аквапарк-мини от 25.000/2 ч
ст.м. "Немига"
713
-50%
Бассейн + сауна + гейзер + гидромассаж + каскад + восходящий душ
ст.м. "Фрунзенская", 7 дн. в неделю
60683
-50%
Посмотреть весь раздел▼
Показать
на карте

# Бесплатные коды (104)

Скидка 60% на брендовую парфюмерию
Доставка
5182
-60%
Код: 0 руб.
Поздравление Деда Мороза всего от 140 000 руб.
г. Минск
84
-65%
Код: 0 руб.
Букеты из роз, тюльпанов и хризантем от 13 500 руб./шт.
ул. Румянцева + доставка
350
-55%
Код: 0 руб.
Зимняя мужская куртка + шарф в подарок!
Доставка
49
-40%
Код: 0 руб.
Вся парфюмерия со скидкой 50% от 135 000 руб. + бонус!
Доставка по Минску и РБ
4555
-50%
Код: 0 руб.
Теплые перчатки для сенсорного экрана от 50 000 руб.
р-н Комаровки
2181
-72%
Код: 0 руб.
Мягкие плюшевые медведи всего от 199 000 руб.
р-н Комаровки + Доставка
66
-50%
Код: 0 руб.
Роботы-пылесосы: покупка или прокат от 300 000 руб./нед.
Доставка
10
-50%
Код: 0 руб.
Магниты с Вашим изображением от 6 000 руб.
ст.м. "Михалово" + Доставка
1480
-50%
Код: 0 руб.
Посмотреть весь раздел▼
Показать
на карте

# Туризм (432)

Визы (35) Популярный туризм (16) Беларусь (26) Болгария (11) Греция (17) Египет (19) Испания (14) Италия (14) Латвия (36) Литва (61) ОАЭ (10) Польша (62) Россия (23) Турция (13) Украина (9) Франция (15) Черногория (3) Чехия (32) Санкт-Петербург (8) Другие страны (123) Европа авиа (40) Европа автобус (202) Горнолыжный отдых (17) Море (84) На выходные (57) Паломничество (2) Раннее бронирование (58) Шоппинг (44) Израиль (3) Новый год и Рождество (146) Весь Туризм
Компании (57)
Baloo Travel (12) Ecotravel (9) Flytravel (3) Terra Touristic (3) Vispaniu (4) VRK Travel (20) World travel (11) Авангард Надея (1) Алиприана (9) Альтус Тур (8) Анадимтур (8) Бествей (2) БогемияТрэвел (5) Ванда (9) Виста-Трэвэл (4) Владислава Тур (6) Глоубал Трэвэл (14) Два солнца (5) Дельта Тур (5) Дельфин Групп (7) ДиАртис (4) Долина туров (6) Долсан (3) Дриант (6) Колесо путешествий (1) Кэтэлина (9) ЛакиТрэвел (4) МагАвиа-Сервис (3) Манго Тур (3) МАТЭП-90 (4) Маэстро Тур (5) Ньюс-Трэвэл (8) Одиссея-Тур (16) Ореол-Трэвел (3) Оскор (2) Остров-тур (16) Планета Трэвел (4) Сакура Трэвл (7) Сити-Бриз (3) Си трэвел (7) Сказочный Тур (4) СтарБусТрэвел (1) Степ бай степ тревел (3) Сэвэн Трэвел (13) Территория отдыха (3) Трио-Трэвел (4) Хоттабыч (2) Хэппи турс (14) Центркурорт (1) Шампань (11) ЭкологияТур (12) Эпифора (2) Ювента-Марина (6) Юника-Нэт (9) Юнитрэвел (2) Яваштур (1) Янг Туристик (3)
Авторский тур в Венгрию + Relax и Spa за 295€/7 дней
Выезд: 21.12.2014 г.
7
-10€
Новогодние тайны Львова от 85$/от 2 дней
Выезд: 30.12.14 г.
14
-15$
Многократные шенген-визы в Польшу, Литву, Италию, Францию, Грецию и др.
г-ца "Минск"
1375
-50€
Новый год Вильнюс-Каунас- Тракай за 95€/3 дня
Выезд: 31 декабря
7
-20€
Раннее бронирование: Греция из Минска!
Вылеты: май - сентябрь 2015 г.
491
-7%
Шедевры новогоднего Петербурга за 85$/5 дней
Выезд: 30.12
2
-25$
Код: 0 руб.
Посмотреть весь раздел▼
Показать
на карте

# Детям (97)

Товары (33) Обучение и курсы (14) Развлечения (27) Одежда и обувь (5) Другое (14) Весь Детям
Творческие студии для детей всего за 48 000 руб./занятие
р-н ул. Маяковского
5
-53%
Карусели, автоматы, аквама- кияж в Kazki за 55 000 руб.
пр-т Победителей, аквапарк "Лебяжий"
429
-50%
Бесплатное логопедическое занятие для детей 2-4 лет
р-н ул. Маяковского
17
-100%
Посмотреть весь раздел▼
Показать
на карте

# Одежда (75)

Детская одежда (5) Аксессуары (32) Одежда (17) Купальники и плавки (1) Нижнее белье (13) Обувь (11) Свадьба (1) ТЦ Силуэт (8) Вся Одежда
Модные домашние тапочки-угги всего от 110 000 руб.
р-н Комаровки
311
-36%
Леггинсы и домашние тапочки всего от 80 000 руб.
ст.м. "Площадь Я.Коласа"
4
-36%
Стильные шарфы за 120.000 руб.
ст.м. "Немига"
38
-73%
Посмотреть весь раздел▼
Показать
на карте

# Обучение (52)

Для детей (12) Кулинарные курсы (1) Автошколы (5) Курсы имиджа (5) Курсы фотографии (1) Музыка (1) Повышение квалификации (1) Семинары и тренинги (3) Спорт (8) Танцы (17) Другое (5) Все Обучение
Обучение в автошколе всего от 850 000 руб.
ст.м. "Площадь Победы"
391
-50%
Мастер-класс по приготов- лению суши со скидкой 50%
ст.м. "Площадь Я.Коласа, клуб "Dozari"
81
-50%
Танцы на полотнах, контемп, go-go, пластика от 40.000 руб.
ст.м. "Пролетарская", ст.м. "Московская"
267
-55%
Посмотреть весь раздел▼
Показать
на карте

# Прочие (153)

Для животных (7) Обслуживание компьютера (8) Обучение (17) Печать визиток и полиграфия (6) Печать на предметах (17) Печать фото (10) Прокат (12) Ремонт дома (12) Ремонт одежды (1) Ремонт техники (6) Уборка помещений (1) Фото на документы (5) Фотосессии (17) Химчистка ковров и мягкой мебели (4) Химчистка одежды (1) Другое (43) Все Прочие
Фотокниги, мини-фотокниги от 49 000 руб.
ул. Столетова - ул. Филимонова + Доставка
200
-60%
Срочное фото на документы всего за 29 000 руб.
ст. м. "Немига"
160
-52%
Химчистка дубленок, курток, костюмов со скидкой до 50%
Уручье
4620
-50%
Посмотреть весь раздел▼
Показать
на карте

# Свадьба (35)

Оформление свадебного торжества со скидкой до 50%
Выезд к клиенту
85
-50%
Свадебная фотосъёмка от 250$
Выезд
17
-50%
Гирлянды и дождь LED, елки, хлопушки всего от 12 000 руб.
ст.м. "Площадь Ленина", "Фрунзенская"
1116
-50%
Посмотреть весь раздел▼
Показать
на карте

# Гарантия качества руководителя (16)

Ручная и комплексная мойка авто + нано от 47500 руб.
пр-т Пушкина, г-ца "Орбита"
570
-50%
Гарантия! Комплекс 3в1 для бровей всего за 79 000 руб.
р-н Комаровки
1227
-50%
Перманентный макияж от 320.000 руб.
пр-т Партизанский - МКАД
5128
-60%
Посмотреть весь раздел▼
Показать
на карте

# Акции РБ (22)

Безопасный прокол ушей + сережки всего за 70 000 руб.
бульвар Шевченко
6
-50%
Автомойка без воды Fast&Shine всего от 25 000 руб.!
ул. Ленина
7
-50%
2 билета в 5D в Витебске всего за 30 000 руб.
ж/д вокзал г. Витебска
1
-50%
Посмотреть весь раздел▼
Акция успешно добавлена в избранные